@@ -174,6 +174,11 @@ class Params(object):
         bind = True
         is_pypher = False
 
+        # we want None values to be assigned as the keyword NULL in the
+        # resulting Cypher
+        if value is None:
+            value = __.NULL
+
         if isinstance(value, Param):
             name = value.name
             value = value.value
@@ -921,8 +926,9 @@ class Operator(_BaseLink):
         return self._value
 
     def _set_value(self, value):
+        # None should result to NULL
         if value is None:
-            value = 'null'
+            value = __.NULL
 
         self._value = value
 
